@@ -80,9 +80,12 @@ public:
 
     void initFilters();
     void initRunningApplets();
+    void screenAdded(int screen);
+    void screenRemoved(int screen);
     void containmentDestroyed();
 
     void addContainment(Containment *containment);
+    void removeContainment(Containment *containment);
 
     /**
      * Tracks a new running applet
@@ -138,18 +141,18 @@ void WidgetExplorerPrivate::initFilters()
     QSet<QString> existingCategories = itemModel.categories();
     //foreach (const QString &category, Plasma::Applet::listCategories(application)) {
     QStringList cats;
-    const QList<KPluginInfo> list = PluginLoader::self()->listAppletInfo(QString());
+    const QList<KPluginMetaData> list = PluginLoader::self()->listAppletMetaData(QString());
 
-    for (auto& info : list) {
-        if (!info.isValid()) {
+    for (auto& plugin : list) {
+        if (!plugin.isValid()) {
             continue;
         }
-        if (info.property(QStringLiteral("NoDisplay")).toBool() || info.category() == QLatin1String("Containments") ||
-            info.category().isEmpty()) {
+        if (plugin.rawData().value("NoDisplay").toBool() || plugin.category() == QLatin1String("Containments") ||
+            plugin.category().isEmpty()) {
             // we don't want to show the hidden category
             continue;
         }
-        const QString c = info.category();
+        const QString c = plugin.category();
         if (-1 == cats.indexOf(c)) {
             cats << c;
         }
@@ -230,16 +233,6 @@ QList <QObject *>  WidgetExplorer::widgetsMenuActions()
     return actionList;
 }
 
-QList<QObject *> WidgetExplorer::extraActions() const
-{
-    QList<QObject *> actionList;
-//     foreach (QAction *action, actions()) { // FIXME: where did actions() come from?
-//         actionList << action;
-//     }
-    qWarning() << "extraactions needs reimplementation";
-    return actionList;
-}
-
 void WidgetExplorerPrivate::initRunningApplets()
 {
     //get applets from corona, count them, send results to model
@@ -255,24 +248,49 @@ void WidgetExplorerPrivate::initRunningApplets()
         qWarning() << "WidgetExplorer failed to find corona";
         return;
     }
-
     appletNames.clear();
     runningApplets.clear();
 
+    QObject::connect(c, &Plasma::Corona::screenAdded, q, [this] (int screen) {screenAdded(screen);});
+    QObject::connect(c, &Plasma::Corona::screenRemoved, q, [this] (int screen) {screenRemoved(screen);});
+
     const QList<Containment*> containments = c->containments();
     for (Containment *containment : containments) {
         if (containment->containmentType() == Plasma::Types::DesktopContainment
             && containment->activity() != activitiesConsumer->currentActivity()) {
             continue;
         }
-
-        addContainment(containment);
+        if (containment->screen() != -1) {
+            addContainment(containment);
+        }
     }
 
     //qDebug() << runningApplets;
     itemModel.setRunningApplets(runningApplets);
 }
 
+void WidgetExplorerPrivate::screenAdded(int screen)
+{
+    const QList<Containment*> containments = containment->corona()->containments();
+    for (auto c : containments) {
+        if (c->screen() == screen) {
+            addContainment(c);
+        }
+    }
+    itemModel.setRunningApplets(runningApplets);
+}
+
+void WidgetExplorerPrivate::screenRemoved(int screen)
+{
+    const QList<Containment*> containments = containment->corona()->containments();
+        for (auto c : containments) {
+        if (c->lastScreen() == screen) {
+            removeContainment(c);
+        }
+    }
+    itemModel.setRunningApplets(runningApplets);
+}
+
 void WidgetExplorerPrivate::addContainment(Containment *containment)
 {
     QObject::connect(containment, SIGNAL(appletAdded(Plasma::Applet*)), q, SLOT(appletAdded(Plasma::Applet*)));
@@ -291,6 +309,22 @@ void WidgetExplorerPrivate::addContainment(Containment *containment)
     }
 }
 
+void WidgetExplorerPrivate::removeContainment(Plasma::Containment *containment)
+{
+    containment->disconnect(q);
+    const QList<Applet*> applets = containment->applets();
+    for (auto applet : applets) {
+        if (applet->pluginMetaData().isValid()) {
+            Containment *childContainment = applet->property("containment").value<Containment*>();
+            if (childContainment) {
+                removeContainment(childContainment);
+            }
+            runningApplets[applet->pluginMetaData().pluginId()]--;
+        }
+    }
+}
+
+
 void WidgetExplorerPrivate::containmentDestroyed()
 {
     containment = nullptr;
