@@ -236,11 +236,43 @@ bool DesktopView::event(QEvent *e)
             m_shellSurface = nullptr;
             break;
         }
+    } else if (e->type() == QEvent::FocusOut) {
+        m_krunnerText.clear();
     }
 
     return PlasmaQuick::ContainmentView::event(e);
 }
 
+bool DesktopView::handleKRunnerTextInput(QKeyEvent *e)
+{
+    // allow only Shift and GroupSwitch modifiers
+    if (e->modifiers() & ~Qt::ShiftModifier & ~Qt::GroupSwitchModifier) {
+        return false;
+    }
+    bool krunnerTextChanged = false;
+    const QString eventText = e->text();
+    for (const QChar ch : eventText) {
+        if (!ch.isPrint()) {
+            continue;
+        }
+        if (ch.isSpace() && m_krunnerText.isEmpty()) {
+            continue;
+        }
+        m_krunnerText += ch;
+        krunnerTextChanged = true;
+    }
+    if (krunnerTextChanged) {
+        const QString interface(QStringLiteral("org.kde.krunner"));
+        if (!KAuthorized::authorize(QStringLiteral("run_command"))) {
+            return false;
+        }
+        org::kde::krunner::App krunner(interface, QStringLiteral("/App"), QDBusConnection::sessionBus());
+        krunner.query(m_krunnerText);
+        return true;
+    }
+    return false;
+}
+
 void DesktopView::keyPressEvent(QKeyEvent *e)
 {
     ContainmentView::keyPressEvent(e);
@@ -256,18 +288,9 @@ void DesktopView::keyPressEvent(QKeyEvent *e)
     }
 
     // When a key is pressed on desktop when nothing else is active forward the key to krunner
-    if (!e->modifiers() || e->modifiers() == Qt::ShiftModifier) {
-        const QString text = e->text().trimmed();
-        if (!text.isEmpty() && text[0].isPrint()) {
-            const QString interface(QStringLiteral("org.kde.krunner"));
-            if (!KAuthorized::authorize(QStringLiteral("run_command"))) {
-                return;
-            }
-            org::kde::krunner::App krunner(interface, QStringLiteral("/App"), QDBusConnection::sessionBus());
-            krunner.query(text);
-            e->accept();
-            return;
-        }
+    if (handleKRunnerTextInput(e)) {
+        e->accept();
+        return;
     }
 }
 
@@ -313,6 +336,7 @@ void DesktopView::screenGeometryChanged()
     if (m_shellSurface) {
         m_shellSurface->setPosition(geo.topLeft());
     }
+    emit geometryChanged();
 }
 
 
