@@ -32,15 +32,14 @@ class KCMInit : public QObject
     Q_CLASSINFO("D-Bus Interface", "org.kde.KCMInit")
 	public Q_SLOTS: //dbus
         Q_SCRIPTABLE void runPhase1();
-        Q_SCRIPTABLE void runPhase2();
     public:
         explicit KCMInit( const QCommandLineParser& args );
         ~KCMInit() override;
     private:
         bool runModule(const QString &libName, KService::Ptr service);
         void runModules( int phase );
-        KService::List list;
-        QSet<QString> alreadyInitialized;
+        KService::List m_list;
+        QSet<QString> m_alreadyInitialized;
 };
 
 #endif // MAIN_H
